#!/bin/bash

set -e

P=openssl
V=1.1.1d
B=1

[ -d "$OSGEO4W_REP" ] || { echo OSGEO4W_REP not found; exit 1; }

for ARCH in x86_64 x86; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT="C:\\OSGeo4W"
			BITS=32
			POSTFIX=
			;;

		x86_64)
			export OSGEO4W_ROOT="C:\\OSGeo4W64"
			BITS=64
			POSTFIX=-x64
			;;

		*)
			echo "Unsupported arch $ARCH" >&2
			exit 1
			;;
		esac

		b=Win${BITS}OpenSSL-${V//./_}.exe
		[ -f "$b" ] || wget -q https://slproweb.com/download/$b
		[ -d install-$ARCH ] || ./$b /CURRENTUSER /LOG=install-$ARCH.log /SP- /VERYSILENT /DIR=$(cygpath -am install-$ARCH) /NOICONS /SUPPRESSMSGBOXES /NORESTART

		R=$OSGEO4W_REP/$ARCH/release/$P

		/bin/mkdir -p $R $R/$P-devel install-$ARCH/etc/postinstall

		/bin/cat <<EOF >install-$ARCH/etc/postinstall/$P.bat
dllupdate -oite -copy -reboot "%OSGEO4W_ROOT%\bin\libcrypto-1_1.dll"
dllupdate -oite -copy -reboot "%OSGEO4W_ROOT%\bin\libssl-1_1.dll"
EOF

		cat <<EOF >$R/setup.hint
sdesc: "OpenSSL Cryptography (Runtime)"
ldesc: "OpenSSL Cryptography (Runtime)"
category: Libs
requires: msvc2015 openssl10
EOF

		cp install-$ARCH/license.txt $R/$P-$V-$B.txt

		tar -C install-$ARCH -cjf $R/$P-$V-$B.tar.bz2 \
			bin/libcrypto-1_1${POSTFIX}.dll \
			bin/libssl-1_1${POSTFIX}.dll \
			etc/postinstall/$P.bat

		tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 \
			osgeo4w/package.sh

		cp install-$ARCH/license.txt $R/$P-devel/$P-$V-$B.txt

		cat <<EOF >$R/$P-devel/setup.hint
sdesc: "OpenSSL Cryptography (Development)"
ldesc: "OpenSSL Cryptography (Development)"
category: Libs
requires: openssl
external-source: openssl
EOF
		tar -C install-$ARCH -cjf $R/$P-devel/$P-devel-$V-$B.tar.bz2 \
			bin/openssl.exe \
			include/openssl \
			lib/libcrypto.lib \
			lib/libssl.lib
			
		./install-$ARCH/unins000.exe /log=uninstall-$ARCH.log /VERYSILENT /NoRestart /SuppressMsgBoxes
	)
done
